FlutterAgoraLiveEventHandler class
Constructors
- FlutterAgoraLiveEventHandler({dynamic onError(int error)?, dynamic onConnectionChanged(int state, int reason)?, dynamic onJoinChannelSuccess(int error)?, dynamic onLeaveChannel()?, dynamic onUserJoined(int error)?, dynamic onUserOffline(int state, int reason)?, dynamic onFirstRemoteVideoFrame(int error)?, dynamic onFirstRemoteVideoDecoded(int error)?, dynamic onRemoteVideoStateChanged(int error)?, dynamic onRemoteVideoMuted(int error)?, dynamic onLivePipCloseClicked()?, dynamic onLivePipFullScreenClicked()?})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onConnectionChanged → dynamic Function(int state, int reason)?
-
正在连接
final
- onError → dynamic Function(int error)?
-
加入直播间错误
final
- onFirstRemoteVideoDecoded → dynamic Function(int error)?
-
第一帧画面解码
final
- onFirstRemoteVideoFrame → dynamic Function(int error)?
-
第一帧画面
final
- onJoinChannelSuccess → dynamic Function(int error)?
-
加入直播间成功
final
- onLeaveChannel → dynamic Function()?
-
离开房间
final
- onLivePipCloseClicked → dynamic Function()?
-
点击画中画关闭按钮
final
- onLivePipFullScreenClicked → dynamic Function()?
-
点击画中画全屏按钮
final
- onRemoteVideoMuted → dynamic Function(int error)?
-
远端用户取消或恢复发布视频流回调
final
- onRemoteVideoStateChanged → dynamic Function(int error)?
-
远端视频状态改变
final
- onUserJoined → dynamic Function(int error)?
-
远端用户加入
final
- onUserOffline → dynamic Function(int state, int reason)?
-
远端用户离开
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited